@@ -295,6 +295,8 @@ def _check_file_syntax(filename, override_lang=None, enforce=True):
     Checks that the code in FILENAME parses, attempting to autodetect
     the language if necessary.
 
+    Raises IOError if the file cannot be read.
+
     Raises subprocess.CalledProcessError if there is a problem, and
     "enforce" is True.
     """
@@ -315,6 +317,10 @@ def _check_file_syntax(filename, override_lang=None, enforce=True):
         # Ignore other kinds of files.
         return
 
+    # Do a test read of the file to catch errors like the file not
+    # existing or not being readable.
+    open(filename)
+
     try:
         checker_fn(filename)
     except subprocess.CalledProcessError as e:
@@ -343,7 +349,10 @@ def _verify_app_source_dir(src_dir, enforce=True):
                 entry_point_file = os.path.abspath(os.path.join(src_dir, manifest['runSpec']['file']))
                 try:
                     _check_file_syntax(entry_point_file, override_lang=manifest['runSpec']['interpreter'], enforce=enforce)
-                except subprocess.CalledProcessError:
+                except IOError as e:
+                    raise dxpy.app_builder.AppBuilderException(
+                        'Could not open runSpec.file=%r. The problem was: %s' % (entry_point_file, e))
+                except subprocess.CalledProcessError as e:
                     raise dxpy.app_builder.AppBuilderException('Entry point file %s has syntax errors, see above for details. Rerun with --no-check-syntax to proceed anyway.' % (entry_point_file,))
             elif "code" in manifest['runSpec']:
                 try:
@@ -364,6 +373,13 @@ def _verify_app_source_dir(src_dir, enforce=True):
                     'Rerun with --no-check-syntax to proceed anyway.'])
                     raise dxpy.app_builder.AppBuilderException(msg)
 
+    if 'authorizedUsers' in manifest:
+        if not isinstance(manifest['authorizedUsers'], list) or isinstance(manifest['authorizedUsers'], basestring):
+            raise dxpy.app_builder.AppBuilderException('Expected authorizedUsers to be a list of strings')
+        for thing in manifest['authorizedUsers']:
+            if thing != 'PUBLIC' and (not isinstance(thing, basestring) or not re.match("^(org-|user-)", thing)):
+                raise dxpy.app_builder.AppBuilderException('authorizedUsers field contains an entry which is not either the string "PUBLIC" or a user or org ID')
+
     # Check all other files that are going to be in the resources tree.
     # For these we detect the language based on the filename extension.
     # Obviously this check can have false positives, since the app can
@@ -381,6 +397,11 @@ def _verify_app_source_dir(src_dir, enforce=True):
             if not filename.startswith("._"):
                 try:
                     _check_file_syntax(os.path.join(dirpath, filename), enforce=True)
+                except IOError as e:
+                    raise dxpy.app_builder.AppBuilderException(
+                        'Could not open file in resources directory %r. The problem was: %s' %
+                        (os.path.join(dirpath, filename), e)
+                    )
                 except subprocess.CalledProcessError:
                     # Suppresses errors from _check_file_syntax so we
                     # only print a nice error message
@@ -647,7 +668,8 @@ def build_and_upload_locally(src_dir, mode, overwrite=False, archive=False, publ
         if not do_upload_step:
             return
 
-        bundled_resources = dxpy.app_builder.upload_resources(src_dir, project=working_project) if not dry_run else []
+        bundled_resources = dxpy.app_builder.upload_resources(
+            src_dir, project=working_project, folder=override_folder) if not dry_run else []
 
         try:
             # TODO: the "auto" setting is vestigial and should be removed.
