@@ -547,21 +547,24 @@ def resolve_existing_path(path, expected=None, ask_to_resolve=True, expected_cla
                     found_valid_class = True
         if not found_valid_class:
             return None, None, None
+
+        if 'project' not in describe:
+            if project != dxpy.WORKSPACE_ID:
+                describe['project'] = project
+            elif dxpy.WORKSPACE_ID is not None:
+                describe['project'] = dxpy.WORKSPACE_ID
         try:
-            if 'project' not in describe:
-                if project != dxpy.WORKSPACE_ID:
-                    describe['project'] = project
-                elif dxpy.WORKSPACE_ID is not None:
-                    describe['project'] = dxpy.WORKSPACE_ID
             desc = dxpy.DXHTTPRequest('/' + entity_name + '/describe', describe)
-        except:
+        except Exception as details:
             if 'project' in describe:
                 # Now try it without the hint
                 del describe['project']
                 try:
                     desc = dxpy.DXHTTPRequest('/' + entity_name + '/describe', describe)
-                except BaseException as details:
+                except Exception as details:
                     raise ResolutionError(str(details))
+            else:
+                raise ResolutionError(str(details))
         result = {"id": entity_name, "describe": desc}
         if ask_to_resolve and not allow_mult:
             return project, folderpath, result
@@ -647,6 +650,25 @@ def get_app_from_path(path):
     except dxpy.DXAPIError:
         return None
 
+def resolve_app(path):
+    '''
+    :param path: A string which is supposed to identify an app
+    :type path: string
+    :returns: The describe hash of the app object
+    :raises: :exc:`ResolutionError` if it cannot be found
+
+    *path* is expected to have one of the following forms:
+
+    - hash ID, e.g. "app-B8GZ8bQ0xky1PKY6FjGQ000J"
+    - named ID, e.g. "app-myapp"
+    - named ID with alias (version or tag), e.g. "app-myapp/1.2.0"
+    '''
+    desc = get_app_from_path(path)
+    if desc is None:
+        raise ResolutionError('The given path \"' + path + '\" could not be resolved to an accessible app')
+    else:
+        return desc
+
 def resolve_to_objects_or_project(path, all_matching_results=False):
     '''
     :param path: Path to resolve
